#!/usr/bin/python3
__copyright__ = """
 SPDX-FileCopyrightText: Copyright (c) 2024-2025 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 SPDX-License-Identifier: BSD-3-Clause

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:

 1. Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.

 3. Neither the name of the copyright holder nor the names of its
 contributors may be used to endorse or promote products derived from
 this software without specific prior written permission.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""

# Module that contain class OperationHandler

from ..simparse.simparse import SimArgParse
from .version.version import VersionHandler
from .info.info import InfoHandler
from .extcommand.extcommand import ExtCommandHandler
from .dpaobjects.partition.partition import PartitionHandler
from .dpaobjects.group.group import GroupHandler


# Class of Base Operation Handler - parent class for operations
class SimMainHandler:
    def __init__(self):
        params = SimArgParse().parse()
        handler = self._get_handler_obj(params.cmd)
        if hasattr(params, 'device'):
            self._yamlfile = f"/tmp/sim_{params.device}.yml"
        else:
            self._yamlfile = None
        self._handler_obj = handler(params, self._yamlfile)

    def _get_handler_obj(self, name):
        handler_dict = {"partition": PartitionHandler,
                        "eu_group": GroupHandler,
                        "info": InfoHandler,
                        "ext_command": ExtCommandHandler,
                        "version": VersionHandler}
        return handler_dict[name]

    def handle(self):
        self._handler_obj.operation()

    def update_db(self):
        if self._handler_obj.need_update:
            self._handler_obj.write_data(self._yamlfile)
