#!/usr/bin/python3
__copyright__ = """
 SPDX-FileCopyrightText: Copyright (c) 2024-2025 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 SPDX-License-Identifier: BSD-3-Clause

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:

 1. Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.

 3. Neither the name of the copyright holder nor the names of its
 contributors may be used to endorse or promote products derived from
 this software without specific prior written permission.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""

# Module that contain class OperationHandler

import sys
from ..simenums.simenums import DPADB
from ..simyaml.simyaml import YAMLSimOperations
from ..simdatabases.simextdb import SimDataManager
from ..simdatabases.simintdb import SimDPAData


# Class of Base Operation Handler - parent class for operations
class OperationHandler:
    def __init__(self, arg_params, filename):
        self._need_update = False
        self._params = arg_params

        self._yamlfile = filename
        if self._is_read_cfg_file():
            self._data = SimDataManager().read_data(self._yamlfile)

            for key, value in self._data[DPADB.CHIP].items():
                setattr(self, key, value)

            self._dpa_obj = SimDPAData(self._data)

    def _get_subfunction(self):
        subfunc_dict = {}
        return subfunc_dict[self._params.subcommand]

    def _get_subfunction(self):
        subfunc_dict = {}
        return subfunc_dict[self._params.subcommand]

    def operation(self):
        func_oper = self._get_subfunction()
        func_oper()

    def write_data(self, filename):
        YAMLSimOperations().update_database(self._data, filename)

    def _set_update(self):
        self._need_update = True

    def _is_read_cfg_file(self):
        return True

    @property
    def need_update(self):
        return self._need_update

    def _error_message(self, msg):
        print(msg)
        sys.exit(1)
